from metasim.cfg.objects import PrimitiveCubeMetaCfg, RigidObjMetaCfg
from metasim.cfg.tasks.base_task_metacfg import BaseTaskMetaCfg
from metasim.constants import BenchmarkType, PhysicStateType, TaskType
from metasim.utils import configclass


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure203MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/7138f5e13b2e4e17975c23ba5584164b/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/7138f5e13b2e4e17975c23ba5584164b_tape_measure_upright/20240826-213930_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure204MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/7138f5e13b2e4e17975c23ba5584164b/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/7138f5e13b2e4e17975c23ba5584164b_tape_measure_upright/20240826-211811_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure205MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/7138f5e13b2e4e17975c23ba5584164b/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/7138f5e13b2e4e17975c23ba5584164b_tape_measure_upright/20240826-220445_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure206MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/7138f5e13b2e4e17975c23ba5584164b/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/7138f5e13b2e4e17975c23ba5584164b_tape_measure_upright/20240826-213744_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure207MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/7138f5e13b2e4e17975c23ba5584164b/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/7138f5e13b2e4e17975c23ba5584164b_tape_measure_upright/20240826-213915_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure208MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/7138f5e13b2e4e17975c23ba5584164b/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/7138f5e13b2e4e17975c23ba5584164b_tape_measure_upright/20240826-213640_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure748MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d1d1c4b27f5c45a29910830e268f7ee2/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d1d1c4b27f5c45a29910830e268f7ee2_tape_measure_upright/20240826-215928_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure749MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d1d1c4b27f5c45a29910830e268f7ee2/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d1d1c4b27f5c45a29910830e268f7ee2_tape_measure_upright/20240826-213034_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure750MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d1d1c4b27f5c45a29910830e268f7ee2/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d1d1c4b27f5c45a29910830e268f7ee2_tape_measure_upright/20240826-221547_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure751MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d1d1c4b27f5c45a29910830e268f7ee2/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d1d1c4b27f5c45a29910830e268f7ee2_tape_measure_upright/20240826-213657_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure752MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d1d1c4b27f5c45a29910830e268f7ee2/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d1d1c4b27f5c45a29910830e268f7ee2_tape_measure_upright/20240826-212634_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure753MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d1d1c4b27f5c45a29910830e268f7ee2/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d1d1c4b27f5c45a29910830e268f7ee2_tape_measure_upright/20240826-215106_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure1190MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/11307d06bb254318b95021d68c6fa12f/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/11307d06bb254318b95021d68c6fa12f_tape_measure_upright/20240826-212239_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure1191MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/11307d06bb254318b95021d68c6fa12f/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/11307d06bb254318b95021d68c6fa12f_tape_measure_upright/20240826-212757_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure1192MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/11307d06bb254318b95021d68c6fa12f/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/11307d06bb254318b95021d68c6fa12f_tape_measure_upright/20240826-212708_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure1193MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/11307d06bb254318b95021d68c6fa12f/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/11307d06bb254318b95021d68c6fa12f_tape_measure_upright/20240826-211321_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure1194MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/11307d06bb254318b95021d68c6fa12f/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/11307d06bb254318b95021d68c6fa12f_tape_measure_upright/20240826-212938_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure1195MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/11307d06bb254318b95021d68c6fa12f/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/11307d06bb254318b95021d68c6fa12f_tape_measure_upright/20240826-213055_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure1299MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/1574b13827734d54b6d9d86be8be71d1/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/1574b13827734d54b6d9d86be8be71d1_tape_measure_upright/20240826-215231_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure1300MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/1574b13827734d54b6d9d86be8be71d1/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/1574b13827734d54b6d9d86be8be71d1_tape_measure_upright/20240826-213829_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure1301MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/1574b13827734d54b6d9d86be8be71d1/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/1574b13827734d54b6d9d86be8be71d1_tape_measure_upright/20240826-211520_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure1302MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/1574b13827734d54b6d9d86be8be71d1/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/1574b13827734d54b6d9d86be8be71d1_tape_measure_upright/20240826-220048_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure1303MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/1574b13827734d54b6d9d86be8be71d1/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/1574b13827734d54b6d9d86be8be71d1_tape_measure_upright/20240826-215534_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotTapeMeasureUprightTapeMeasure1304MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="tape measure",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/1574b13827734d54b6d9d86be8be71d1/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/1574b13827734d54b6d9d86be8be71d1_tape_measure_upright/20240826-220712_no_interaction/trajectory-unified_wo_traj_v2.pkl"



import numpy as np
import plotly.graph_objects as go


def plot_point_cloud(pts, **kwargs):
    return go.Scatter3d(x=pts[:, 0], y=pts[:, 1], z=pts[:, 2], mode="markers", **kwargs)


def plot_mesh(mesh, pos=None, rot=None, color="lightblue", opacity=1.0, name="mesh", **kwargs):
    verts = mesh.vertices
    if rot is not None:
        verts = np.matmul(rot, verts.T).T
    if pos is not None:
        verts = verts + pos[None]
    return go.Mesh3d(
        x=verts[:, 0],
        y=verts[:, 1],
        z=verts[:, 2],
        i=mesh.faces[:, 0],
        j=mesh.faces[:, 1],
        k=mesh.faces[:, 2],
        color=color,
        opacity=opacity,
        name=name,
        showlegend=True,
    )



from metasim.cfg.checkers import JointPosShiftChecker
from metasim.cfg.tasks.base_task_metacfg import BaseTaskMetaCfg
from metasim.constants import BenchmarkType, TaskType
from metasim.utils import configclass


@configclass
class OpenDrawerMetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.CALVIN
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    checker = JointPosShiftChecker(
        obj_name="table",
        joint_name="base__drawer",
        threshold=0.12,
    )



from __future__ import annotations

from loguru import logger as log

from metasim.cfg.objects import BaseObjMetaCfg
from metasim.utils.configclass import configclass

try:
    from metasim.sim.base import BaseSimHandler
except:
    pass


@configclass
class BaseChecker:
    def reset(self, handler: BaseSimHandler, env_ids: list[int] | None = None):
        pass

    def check(self, handler: BaseSimHandler):
        import torch

        log.warning("Checker not implemented, task will never succeed")
        return torch.zeros(handler.num_envs, dtype=torch.bool)

    def get_debug_viewers(self) -> list[BaseObjMetaCfg]:
        return []



from __future__ import annotations

#########################################
### Add command line arguments
#########################################
from dataclasses import dataclass

import tyro


@dataclass
class Args:
    source_robot: str
    target_robots: list[str]
    tasks: list[str] | None = None
    source_path: str | None = None
    target_path: str | None = None
    device: str = "cuda:0"
    ignore_ground_collision: bool = False
    viz: bool = False

    def __post_init__(self):
        assert self.tasks is not None or (self.source_path is not None and self.target_path is not None), (
            "Either tasks, or both source_path and target_path must be provided"
        )


args = tyro.cli(Args)


#########################################
### Normal code
#########################################
import os
from copy import deepcopy

import numpy as np
import rootutils
import torch
from curobo.types.math import Pose
from loguru import logger as log
from pytorch3d import transforms
from rich.logging import RichHandler
from tqdm import tqdm, trange

rootutils.setup_root(__file__, pythonpath=True)
log.configure(handlers=[{"sink": RichHandler(), "format": "{message}"}])

from glob import glob

from metasim.utils.demo_util.loader import load_traj_file, save_traj_file
from metasim.utils.kinematics_utils import (
    ee_pose_from_tcp_pose,
    get_curobo_models,
    tcp_pose_from_ee_pose,
)
from metasim.utils.setup_util import get_robot, get_task

NUM_SEED = 20


def single(source_path, target_path):
    if args.viz:
        from plotly import graph_objects as go

        from metasim.utils.viz_utils import plot_point_cloud

    # Robot configurations
    src_cfg = get_robot(args.source_robot)
    target_robot_cfgs = [get_robot(r) for r in args.target_robots]

    src_kin, src_fk, src_ik = get_curobo_models(src_cfg, args.ignore_ground_collision)
    tgts_ik = [get_curobo_models(cfg, args.ignore_ground_collision)[2] for cfg in target_robot_cfgs]

    # Prepare file structure
    demo_data = load_traj_file(source_path)

    if "ur5e_2f85" in args.target_robots:
        assert len(args.target_robots) == 1, "Only one target robot is supported when retargetting to UR5e_2F85"
        for k, v in demo_data.items():
            for i in range(len(v)):
                demo_data[k][i]["actions"] = demo_data[k][i]["actions"][30:]
                if demo_data[k][i].get("states", None) is not None:
                    demo_data[k][i]["states"] = demo_data[k][i]["states"][30:]

    source_demo_data = demo_data[src_cfg.name]
    n_demo = len(source_demo_data)
    episode_lengths = torch.tensor(
        [len(source_demo["actions"]) for source_demo in source_demo_data], dtype=torch.int, device=args.device
    )
    max_episode_len = episode_lengths.max().item()

    # Compute source trajectory: (JS pose ->) EE pose -> TCP pose
    arm_joint_names = [jn for jn, jn_cfg in src_cfg.actuators.items() if not jn_cfg.is_ee]
    gripper_joint_names = [jn for jn, jn_cfg in src_cfg.actuators.items() if jn_cfg.is_ee]
    curobo_joints = src_ik.robot_config.cspace.joint_names

    robot_pos = np.stack(
        [np.array(source_demo["init_state"][src_cfg.name]["pos"]) for source_demo in source_demo_data],
        axis=0,
    )
    robot_quat = np.stack(
        [np.array(source_demo["init_state"][src_cfg.name]["rot"]) for source_demo in source_demo_data],
        axis=0,
    )
    robot_pos = torch.from_numpy(robot_pos).to(args.device).float()
    robot_quat = torch.from_numpy(robot_quat).to(args.device).float()
    robot_rotmat = transforms.quaternion_to_matrix(robot_quat)

    robot_q_traj = np.stack(
        [
            np.pad(
                np.asarray([
                    [a["dof_pos_target"][j] for j in (arm_joint_names + gripper_joint_names)]
                    for a in source_demo["actions"]
                ]),
                [(0, max_episode_len - len(source_demo["actions"])), (0, 0)],
                mode="edge",
            )
            for source_demo in source_demo_data
        ],
        axis=0,
    )

    # Align with cuRobo: Some robot does not have gripper joints
    robot_q_traj = torch.from_numpy(robot_q_traj).to(args.device).float()[..., : len(curobo_joints)]

    ee_act_traj = np.stack(
        [
            np.pad(
                np.asarray([[a["dof_pos_target"][j] for j in gripper_joint_names] for a in source_demo["actions"]]),
                [(0, max_episode_len - len(source_demo["actions"])), (0, 0)],
                mode="edge",
            )
            for source_demo in source_demo_data
        ],
        axis=0,
    )
    ee_act_traj = torch.from_numpy(ee_act_traj).to(args.device).float()

    if "ee_pose_target" in source_demo_data[0]["actions"][0]:
        src_ee_pos_traj = np.stack(
            [
                np.pad(
                    np.asarray([a["ee_pose_target"]["pos"] for a in source_demo["actions"]]),
                    [(0, max_episode_len - len(source_demo["actions"])), (0, 0)],
                    mode="edge",
                )
                for source_demo in source_demo_data
            ],
            axis=0,
        )
        src_ee_quat_traj = np.stack(
            [
                np.pad(
                    np.asarray([a["ee_pose_target"]["rot"] for a in source_demo["actions"]]),
                    [(0, max_episode_len - len(source_demo["actions"])), (0, 0)],
                    mode="edge",
                )
                for source_demo in source_demo_data
            ],
            axis=0,
        )
        ee_act_traj = np.stack(
            [
                np.pad(
                    np.array([a["ee_pose_target"]["gripper_joint_pos"] for a in source_demo["actions"]]),
                    [(0, max_episode_len - len(source_demo["actions"])), (0, 0)],
                    mode="edge",
                )
                for source_demo in source_demo_data
            ],
            axis=0,
        )
        src_ee_pos_traj = torch.from_numpy(src_ee_pos_traj).to(args.device).float()
        src_ee_quat_traj = torch.from_numpy(src_ee_quat_traj).to(args.device).float()
    else:
        # The EE information are missing, compute from JS pose
        log.warning("EE pose information is missing, computing from joint space pose")
        src_ee_pos_traj, src_ee_quat_traj = [], []
        for i_traj in trange(len(source_demo_data), desc=f"Computing EE pose for source robot: {src_cfg.name}"):
            # JS pose -> EE pose (local) -> EE pose (world)
            ee_traj, quat_traj = src_fk(robot_q_traj[i_traj].contiguous())
            ee_traj_world = torch.matmul(ee_traj, robot_rotmat[i_traj].T) + robot_pos[i_traj]
            quat_traj_world = transforms.quaternion_multiply(robot_quat[i_traj], quat_traj)
            # for i_step in range(len(source_demo_data[i_traj]["actions"])):
            #     source_demo_data[i_traj]["actions"][i_step]["ee_pose_target"] = {
            #         "pos": ee_traj_world[i_step].cpu().numpy().tolist(),
            #         "rot": quat_traj_world[i_step].cpu().numpy().tolist(),
            #         # Average joint pose of two fingers
            #         "gripper_joint_pos": ee_act_traj[i_traj, i_step].mean().item(),
            #     }
            src_ee_pos_traj.append(ee_traj.clone())
            src_ee_quat_traj.append(quat_traj.clone())

        # These are still in the robot's local frame (for solving IK)
        src_ee_pos_traj = torch.stack(src_ee_pos_traj, dim=0)
        src_ee_quat_traj = torch.stack(src_ee_quat_traj, dim=0)

    tcp_pos_traj, tcp_quat_traj = tcp_pose_from_ee_pose(src_cfg, src_ee_pos_traj, src_ee_quat_traj)

    tcp_pos_traj = tcp_pos_traj.reshape(n_demo, max_episode_len, 3)
    tcp_quat_traj = tcp_quat_traj.reshape(n_demo, max_episode_len, 4)

    # Visualziation
    to_plot = []
    if args.viz:
        # for i in range(0, len(src_ee_pos_traj), 32):
        #     robot_mesh = source_robot_kin_model.get_robot_as_mesh(robot_q_traj[0, i : i + 1].contiguous())
        #     to_plot.append(plot_mesh(robot_mesh))
        to_plot.append(
            plot_point_cloud(
                src_ee_pos_traj[0].cpu().numpy(),
                name=f"Source: {src_cfg.name}",
                marker=dict(color=ee_act_traj[0].cpu().numpy()),
            )
        )

    # For each target embodiment, compute target trajecotry via IK: TCP pose -> EE pose -> JS pose
    for i_robot, (tgt_cfg, tgt_ik) in enumerate(zip(target_robot_cfgs, tgts_ik)):
        tgt_robot_demo_data = deepcopy(source_demo_data)
        current_q = None
        succ = torch.ones([n_demo], dtype=torch.bool, device=args.device)

        target_dof = len(tgt_ik.robot_config.cspace.joint_names)
        result_q = torch.zeros([n_demo, max_episode_len, target_dof], device=args.device)

        tgt_ee_pos_traj = torch.zeros([n_demo, max_episode_len, 3], device=args.device)
        tgt_ee_quat_traj = torch.zeros([n_demo, max_episode_len, 4], device=args.device)

        log.info(f"Retargetting: {src_cfg.name} -> {tgt_cfg.name}")
        tt = trange(max_episode_len, desc=f"{src_cfg.name} -> {tgt_cfg.name}")

        for t in tt:
            # Only solve IK for unfinished and unfailed trajectories
            valid_idx = torch.where((t <= episode_lengths) * succ)[0]
            if len(valid_idx) == 0:
                log.error("gg")
                break

            n_succ, n_fail = ((t >= episode_lengths - 1) * succ).sum(), (~succ).sum()

            tgt_ee_pos_traj[valid_idx, t], tgt_ee_quat_traj[valid_idx, t] = ee_pose_from_tcp_pose(
                tgt_cfg, tcp_pos_traj[valid_idx, t], tcp_quat_traj[valid_idx, t]
            )

            seed_config = result_q[:, t - 1 : t].tile([1, NUM_SEED, 1])
            result = tgt_ik.solve_batch(
                Pose(tgt_ee_pos_traj[:, t], tgt_ee_quat_traj[:, t]), seed_config=seed_config if t > 0 else None
            )

            result_q[valid_idx, t] = result.solution[valid_idx, 0]
            succ[valid_idx] = succ[valid_idx] * result.success.squeeze()[valid_idx]

            tt.set_description(
                f"{src_cfg.name} -> {tgt_cfg.name} | {n_succ.item()!s} succ | {n_fail.item()!s} fail | {n_demo!s} total"
            )
            tt.refresh()

        if args.viz:
            to_plot.append(plot_point_cloud(tgt_ee_pos_traj[0].cpu().numpy(), name=tgt_cfg.name))

        src_release_q = torch.tensor([[src_cfg.gripper_release_q]]).to(args.device).tile([n_demo, max_episode_len, 1])
        src_actuate_q = torch.tensor([[src_cfg.gripper_actuate_q]]).to(args.device).tile([n_demo, max_episode_len, 1])
        tgt_release_q = torch.tensor([[tgt_cfg.gripper_release_q]]).to(args.device).tile([n_demo, max_episode_len, 1])
        tgt_actuate_q = torch.tensor([[tgt_cfg.gripper_actuate_q]]).to(args.device).tile([n_demo, max_episode_len, 1])
        src_ee_act_rel = torch.abs(ee_act_traj - src_release_q) / torch.abs(src_actuate_q - src_release_q)
        src_ee_act_rel = src_ee_act_rel.mean(axis=-1)  # Avg over two fingers

        if tgt_cfg.ee_binary_action:
            src_ee_act_rel = (src_ee_act_rel > 0.5).float()
        src_ee_act_rel = src_ee_act_rel.unsqueeze(-1).tile([1, 1, tgt_release_q.shape[-1]])
        ee_act_traj = src_ee_act_rel * tgt_actuate_q + (1 - src_ee_act_rel) * tgt_release_q
        result_q = torch.cat([result_q, ee_act_traj], dim=-1)
        tgt_robot_joints = list(tgt_cfg.actuators.keys())

        # tgt_ee_pos_traj_world = torch.matmul(tgt_ee_pos_traj, robot_rotmat.permute(0, 2, 1)) + robot_pos.unsqueeze(1)
        # tgt_ee_quat_traj_world = transforms.quaternion_multiply(robot_quat, tgt_ee_quat_traj)

        log.info(f"Success rate: {(succ.float().mean().item() * 100):.2f}%, saving trajectories...")
        for i_succ in tqdm(torch.where(succ)[0], desc=f"Saving trajectories for {tgt_cfg.name}"):
            for i_step in range(episode_lengths[i_succ]):
                tgt_robot_demo_data[i_succ]["actions"][i_step]["dof_pos_target"] = dict(
                    zip(tgt_robot_joints, result_q[i_succ, i_step].cpu().numpy().tolist())
                )
                # tgt_robot_demo_data[i_succ]["actions"][i_step]["ee_pose_target"] = {
                #     "pos": tgt_ee_pos_traj_world[i_succ, i_step].cpu().numpy().tolist(),
                #     "rot": tgt_ee_quat_traj_world[i_succ, i_step].cpu().numpy().tolist(),
                #     "gripper_joint_pos": ee_act_traj[i_succ, i_step].mean().item,
                # }
            tgt_robot_demo_data[i_succ]["init_state"][tgt_cfg.name] = {
                "dof_pos": dict(zip(tgt_robot_joints, result_q[i_succ, 0].cpu().numpy().tolist())),
                "pos": robot_pos[i_succ].cpu().numpy().tolist(),
                "rot": robot_quat[i_succ].cpu().numpy().tolist(),
            }
            del tgt_robot_demo_data[i_succ]["init_state"][src_cfg.name]

        # Remove failed demos
        fail_succ = torch.where(~succ)[0].cpu().numpy().tolist()
        fail_succ.reverse()
        for i in fail_succ:
            del tgt_robot_demo_data[i]

        log.info(f"Saving trajectories for {tgt_cfg.name}")

        if args.viz:
            go.Figure(to_plot).show()

        if not os.path.exists(os.path.dirname(target_path)):
            os.makedirs(os.path.dirname(target_path), exist_ok=True)
        save_traj_file({tgt_cfg.name: tgt_robot_demo_data}, target_path)
        log.info(f"Retarget finished -> {target_path}")


def main():
    if args.tasks is not None:
        for task_name in args.tasks:
            task = get_task(task_name)
            source_path = task.traj_filepath
            if os.path.isdir(source_path):
                paths = glob(os.path.join(source_path, f"{args.source_robot}_v2.*"))
                assert len(paths) >= 1, f"No trajectories found for {args.source_robot}"
                source_path = paths[0]
            target_path = os.path.join(os.path.dirname(source_path), f"{args.target_robots[0]}_v2.pkl.gz")
            single(source_path, target_path)
    else:
        single(args.source_path, args.target_path)


if __name__ == "__main__":
    main()



# ruff: noqa: F401

from .base_checker import BaseChecker
from .checker_operators import AndOp, NotOp, OrOp
from .checkers import (
    BalanceChecker,
    CrawlChecker,
    DetectedChecker,
    HurdleChecker,
    JointPosChecker,
    JointPosShiftChecker,
    MazeChecker,
    PoleChecker,
    PositionShiftChecker,
    PushChecker,
    RotationShiftChecker,
    RunChecker,
    SitChecker,
    SlideChecker,
    StairChecker,
    StandChecker,
    WalkChecker,
)
from .detectors import (
    Relative2DSphereDetector,
    Relative3DSphereDetector,
    RelativeBboxDetector,
)



from metasim.cfg.objects import PrimitiveCubeMetaCfg, RigidObjMetaCfg
from metasim.cfg.tasks.base_task_metacfg import BaseTaskMetaCfg
from metasim.constants import BenchmarkType, PhysicStateType, TaskType
from metasim.utils import configclass


@configclass
class OpensdorRotRemoteControlForthRemoteControl132MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/89dcd45ac1f04680b76b709357a3dba3/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/89dcd45ac1f04680b76b709357a3dba3_remote_control_forth/20240826-222113_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl133MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/89dcd45ac1f04680b76b709357a3dba3/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/89dcd45ac1f04680b76b709357a3dba3_remote_control_forth/20240826-211429_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl134MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/89dcd45ac1f04680b76b709357a3dba3/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/89dcd45ac1f04680b76b709357a3dba3_remote_control_forth/20240826-220019_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl135MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/89dcd45ac1f04680b76b709357a3dba3/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/89dcd45ac1f04680b76b709357a3dba3_remote_control_forth/20240826-213108_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl136MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/89dcd45ac1f04680b76b709357a3dba3/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/89dcd45ac1f04680b76b709357a3dba3_remote_control_forth/20240826-213129_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl137MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/89dcd45ac1f04680b76b709357a3dba3/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/89dcd45ac1f04680b76b709357a3dba3_remote_control_forth/20240826-220645_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl241MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f1bbc61a42b94ee9a2976ca744f8962e/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f1bbc61a42b94ee9a2976ca744f8962e_remote_control_forth/20240826-222747_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl242MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f1bbc61a42b94ee9a2976ca744f8962e/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f1bbc61a42b94ee9a2976ca744f8962e_remote_control_forth/20240826-222057_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl243MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f1bbc61a42b94ee9a2976ca744f8962e/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f1bbc61a42b94ee9a2976ca744f8962e_remote_control_forth/20240826-222020_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl244MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f1bbc61a42b94ee9a2976ca744f8962e/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f1bbc61a42b94ee9a2976ca744f8962e_remote_control_forth/20240826-223436_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl245MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f1bbc61a42b94ee9a2976ca744f8962e/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f1bbc61a42b94ee9a2976ca744f8962e_remote_control_forth/20240826-211434_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl246MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f1bbc61a42b94ee9a2976ca744f8962e/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f1bbc61a42b94ee9a2976ca744f8962e_remote_control_forth/20240826-213517_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl948MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d72eebbf82be48f0a53e7e8b712e6a66/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d72eebbf82be48f0a53e7e8b712e6a66_remote_control_forth/20240826-214008_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl949MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d72eebbf82be48f0a53e7e8b712e6a66/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d72eebbf82be48f0a53e7e8b712e6a66_remote_control_forth/20240826-211715_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl950MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d72eebbf82be48f0a53e7e8b712e6a66/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d72eebbf82be48f0a53e7e8b712e6a66_remote_control_forth/20240826-221315_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl951MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d72eebbf82be48f0a53e7e8b712e6a66/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d72eebbf82be48f0a53e7e8b712e6a66_remote_control_forth/20240826-220441_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl952MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d72eebbf82be48f0a53e7e8b712e6a66/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d72eebbf82be48f0a53e7e8b712e6a66_remote_control_forth/20240826-221044_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl953MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d72eebbf82be48f0a53e7e8b712e6a66/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d72eebbf82be48f0a53e7e8b712e6a66_remote_control_forth/20240826-215530_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl954MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d72eebbf82be48f0a53e7e8b712e6a66/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d72eebbf82be48f0a53e7e8b712e6a66_remote_control_forth/20240826-213033_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl1051MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/c7ec86e7feb746489b30b4a01c2510af/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/c7ec86e7feb746489b30b4a01c2510af_remote_control_forth/20240826-213501_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl1052MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/c7ec86e7feb746489b30b4a01c2510af/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/c7ec86e7feb746489b30b4a01c2510af_remote_control_forth/20240826-211839_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl1053MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/c7ec86e7feb746489b30b4a01c2510af/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/c7ec86e7feb746489b30b4a01c2510af_remote_control_forth/20240826-213127_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl1054MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/c7ec86e7feb746489b30b4a01c2510af/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/c7ec86e7feb746489b30b4a01c2510af_remote_control_forth/20240826-212253_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl1294MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d28b249d997b46c1b42771d8ce869902/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d28b249d997b46c1b42771d8ce869902_remote_control_forth/20240826-213910_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl1295MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d28b249d997b46c1b42771d8ce869902/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d28b249d997b46c1b42771d8ce869902_remote_control_forth/20240826-213047_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl1296MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d28b249d997b46c1b42771d8ce869902/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d28b249d997b46c1b42771d8ce869902_remote_control_forth/20240826-213412_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl1297MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d28b249d997b46c1b42771d8ce869902/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d28b249d997b46c1b42771d8ce869902_remote_control_forth/20240826-214842_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotRemoteControlForthRemoteControl1298MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="remote control",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/d28b249d997b46c1b42771d8ce869902/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/d28b249d997b46c1b42771d8ce869902_remote_control_forth/20240826-213956_no_interaction/trajectory-unified_wo_traj_v2.pkl"



from __future__ import annotations

from metasim.utils import configclass

from .base_robot_metacfg import BaseActuatorMetaCfg, BaseRobotMetaCfg


@configclass
class Ur5E2F85MetaCfg(BaseRobotMetaCfg):
    name: str = "ur5e_2f85"
    num_joints: int = 12
    filepath: str = "data_isaaclab/robots/UniversalRobots/ur5e/ur5e_2f85_fix.usd"
    enabled_gravity: bool = False
    enabled_self_collisions: bool = False
    actuators: dict[str, BaseActuatorMetaCfg] = {
        "shoulder_pan_joint": BaseActuatorMetaCfg(velocity_limit=2.175),
        "shoulder_lift_joint": BaseActuatorMetaCfg(velocity_limit=2.175),
        "elbow_joint": BaseActuatorMetaCfg(velocity_limit=2.175),
        "wrist_1_joint": BaseActuatorMetaCfg(velocity_limit=2.175),
        "wrist_2_joint": BaseActuatorMetaCfg(velocity_limit=2.61),
        "wrist_3_joint": BaseActuatorMetaCfg(velocity_limit=2.61),
        # "finger_joint": BaseActuatorMetaCfg(velocity_limit=2.61, is_ee=True),
        # "left_inner_finger_joint": BaseActuatorMetaCfg(velocity_limit=2.61, is_ee=True),
        # "left_inner_knuckle_joint": BaseActuatorMetaCfg(velocity_limit=2.61, is_ee=True),
        # "right_inner_finger_joint": BaseActuatorMetaCfg(velocity_limit=2.61, is_ee=True),
        # "right_inner_knuckle_joint": BaseActuatorMetaCfg(velocity_limit=2.61, is_ee=True),
        # "right_outer_knuckle_joint": BaseActuatorMetaCfg(velocity_limit=2.61, is_ee=True),
    }
    joint_limits: dict[str, tuple[float, float]] = {
        "shoulder_pan_joint": (-6.28319, 6.28319),
        "shoulder_lift_joint": (-6.28319, 6.28319),
        "elbow_joint": (-3.14159, 3.14159),
        "wrist_1_joint": (-6.28319, 6.28319),
        "wrist_2_joint": (-6.28319, 6.28319),
        "wrist_3_joint": (-6.28319, 6.28319),
        # "finger_joint": (0.0, 0.785398),
        # "left_inner_finger_joint": (0.0, 0.785398),
        # "left_inner_knuckle_joint": (0.0, 0.785398),
        # "right_inner_finger_joint": (0.0, 0.785398),
        # "right_inner_knuckle_joint": (0.0, 0.785398),
        # "right_outer_knuckle_joint": (0.0, 0.785398),
    }
    ee_prim_path: str = "wrist_3_link"
    gripper_release_q = [0.0, 0.0, 0.0, 0.0, 0.0, 0.0]
    gripper_actuate_q = [0.785398, 0.785398, 0.785398, 0.785398, 0.785398, 0.785398]
    curobo_ref_cfg_name: str = "ur5e_robotiq_2f_140.yml"
    curobo_tcp_rel_pos: tuple[float, float, float] = [0.0, 0.0, -0.0635]
    curobo_tcp_rel_rot: tuple[float, float, float] = [0.0, 0.0, 0.0]



from metasim.cfg.objects import ArticulationObjMetaCfg, RigidObjMetaCfg
from metasim.constants import PhysicStateType
from metasim.utils import configclass

from .rlbench_task_metacfg import RLBenchTaskMetaCfg


@configclass
class PressSwitchMetaCfg(RLBenchTaskMetaCfg):
    episode_length = 200
    traj_filepath = "roboverse_data/trajs/rlbench/press_switch/v2"
    objects = [
        ArticulationObjMetaCfg(
            name="switch_main",
            filepath="roboverse_data/assets/rlbench/press_switch/switch_main/usd/switch_main.usd",
        ),
        RigidObjMetaCfg(
            name="task_wall",
            filepath="roboverse_data/assets/rlbench/press_switch/task_wall/usd/task_wall.usd",
            physics=PhysicStateType.GEOM,
        ),
    ]
    # TODO: add checker



from metasim.cfg.checkers import DetectedChecker, RelativeBboxDetector
from metasim.cfg.objects import RigidObjMetaCfg
from metasim.constants import BenchmarkType, TaskType
from metasim.utils import configclass

from ...base_task_metacfg import BaseTaskMetaCfg


@configclass
class Livingroom1PickAlphabetSoupMetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.LIBERO
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 250

    objects = [
        RigidObjMetaCfg(
            name="alphabet_soup",
            filepath="data_isaaclab/assets/rlbench/close_box/box_base.usd",
            urdf_path="data_isaaclab/assets/rlbench_urdf/close_box/box_base_unique.urdf",
            mjcf_path="data_isaaclab/assets_mujoco/libero/stable_hope_objects/alphabet_soup/alphabet_soup.xml",
        ),
        RigidObjMetaCfg(
            name="basket",
            filepath="data_isaaclab/assets/rlbench/close_box/box_base.usd",
            urdf_path="data_isaaclab/assets/rlbench_urdf/close_box/box_base_unique.urdf",
            mjcf_path="data_isaaclab/assets_mujoco/libero/stable_scanned_objects/basket/basket.xml",
        ),
        RigidObjMetaCfg(
            name="cream_cheese",
            filepath="data_isaaclab/assets/rlbench/close_box/box_base.usd",
            urdf_path="data_isaaclab/assets/rlbench_urdf/close_box/box_base_unique.urdf",
            mjcf_path="data_isaaclab/assets_mujoco/libero/stable_hope_objects/cream_cheese/cream_cheese.xml",
        ),
        RigidObjMetaCfg(
            name="tomato_sauce",
            filepath="data_isaaclab/assets/rlbench/close_box/box_base.usd",
            urdf_path="data_isaaclab/assets/rlbench_urdf/close_box/box_base_unique.urdf",
            mjcf_path="data_isaaclab/assets_mujoco/libero/stable_hope_objects/tomato_sauce/tomato_sauce.xml",
        ),
        RigidObjMetaCfg(
            name="ketchup",
            filepath="data_isaaclab/assets/rlbench/close_box/box_base.usd",
            urdf_path="data_isaaclab/assets/rlbench_urdf/close_box/box_base_unique.urdf",
            mjcf_path="data_isaaclab/assets_mujoco/libero/stable_hope_objects/ketchup/ketchup.xml",
        ),
        RigidObjMetaCfg(
            name="livingroom_table",
            filepath="data_isaaclab/assets/rlbench/close_box/box_base.usd",
            urdf_path="data_isaaclab/assets/rlbench_urdf/close_box/box_base_unique.urdf",
            mjcf_path="data_isaaclab/assets_mujoco/libero/scenes/libero_living_room_tabletop_base_style.xml",
        ),
    ]

    traj_filepath = "data_isaaclab/source_data/libero_tasks/libero_objects/pick_up_the_alphabet_soup_and_place_it_in_the_basket/trajectory-unified_with_object_states_v2.pkl"

    checker = DetectedChecker(
        obj_name="alphabet_soup",
        obj_subpath=None,
        detector=RelativeBboxDetector(
            base_obj_name="basket",
            relative_pos=[0.0, 0.0, 0.07185],
            relative_quat=[1.0, 0.0, 0.0, 0.0],
            checker_lower=[-0.05, -0.05, -0.05],
            checker_upper=[0.05, 0.05, 0.05],
            debug_vis=True,
        ),
    )



from __future__ import annotations

from typing import Any, Dict, List, Optional, TypedDict

import torch

## Basic types
Dof = Dict[str, float]


## Trajectory types
class Action(TypedDict):
    dof_pos_target: Dof


EnvState = Dict[
    str,
    TypedDict(
        "ObjState",
        {
            "pos": torch.Tensor,
            "rot": torch.Tensor,
            "vel": Optional[torch.Tensor],
            "ang_vel": Optional[torch.Tensor],
            "dof_pos": Dof,
            "dof_vel": Optional[Dof],
            "dof_pos_target": Optional[Dof],
            "dof_vel_target": Optional[Dof],
            "dof_torque": Optional[Dof],
            "com": Optional[torch.Tensor],
            "com_vel": Optional[torch.Tensor],
        },
    ),
]


## Gymnasium types
class Obs(TypedDict):
    rgb: torch.Tensor
    depth: torch.Tensor
    states: list[EnvState]


Reward = List[List[float]]  # TODO: you may modify this if necessary
Success = torch.BoolTensor
TimeOut = torch.BoolTensor
Extra = Dict[str, Any]  # XXX
Termination = torch.BoolTensor



import torch

from metasim.constants import TaskType
from metasim.utils import configclass

from ..base_task_metacfg import BaseTaskMetaCfg


@configclass
class WalkerWalkMetaCfg(BaseTaskMetaCfg):
    episode_length = 100
    objects = []
    traj_filepath = None
    task_type = TaskType.LOCOMOTION

    # Constants from DeepMind Control Suite
    _STAND_HEIGHT = 1.2  # Target height for standing reward
    _MOVE_SPEED = 1.0  # Target horizontal speed
    _TERMINATION_HEIGHT = 0.8  # Height at which the walker is considered to have fallen

    def _sigmoid(self, x, value_at_margin=0.1, sigmoid_type="gaussian"):
        """Implements sigmoid functions for the tolerance reward calculation."""
        if sigmoid_type == "gaussian":
            scale = -torch.log(torch.tensor(value_at_margin))
            return torch.exp(-(x**2) * scale)
        elif sigmoid_type == "linear":
            scale = 1.0 - value_at_margin
            return torch.clip(1.0 - x * scale, 0.0, 1.0)
        else:
            # Default to gaussian if unrecognized
            scale = -torch.log(torch.tensor(value_at_margin))
            return torch.exp(-(x**2) * scale)

    def _tolerance(self, x, bounds, margin, sigmoid="gaussian", value_at_margin=0.1):
        """PyTorch version of tolerance function from DM Control."""
        lower, upper = bounds

        # Check if x is within bounds
        in_bounds = torch.logical_and(lower <= x, x <= upper)

        if margin == 0:
            value = torch.where(in_bounds, torch.tensor(1.0), torch.tensor(0.0))
        else:
            # Distance to nearest bound, normalized by margin
            d = torch.where(
                x < lower, (lower - x) / margin, torch.where(x > upper, (x - upper) / margin, torch.tensor(0.0))
            )
            # Apply sigmoid to the distance
            value = torch.where(in_bounds, torch.tensor(1.0), self._sigmoid(d, value_at_margin, sigmoid))

        return value

    def reward_fn(self, states):
        rewards = []
        for env_state in states:
            # Get walker states
            walker_state = env_state["walker"]

            # Extract positions, rotations and velocities
            pos = walker_state["pos"]
            rot = walker_state["rot"]  # quaternion [w, x, y, z]
            vel = walker_state["vel"]

            # 1. Calculate torso height (z position)
            torso_height = pos[2]

            # 2. Calculate upright reward (torso z-axis alignment with world z-axis)
            # Convert quaternion to get torso's up vector
            if len(rot) == 4:  # quaternion [w, x, y, z]
                w, x, y, z = rot
                # z-component of the rotated unit z vector
                torso_upright = 1.0 - 2.0 * (x**2 + y**2)
            else:  # rotation matrix or other format
                # Assuming the third row of rotation matrix represents up vector
                torso_upright = rot[2]

            # 3. Standing reward
            standing = self._tolerance(
                torso_height, bounds=(self._STAND_HEIGHT, float("inf")), margin=self._STAND_HEIGHT / 2, sigmoid="linear"
            )

            # 4. Normalize upright measure to [0, 1]
            upright = (1.0 + torso_upright) / 2.0

            # 5. Combine standing and upright for the stand reward
            stand_reward = (3.0 * standing + upright) / 4.0

            # 6. Calculate horizontal velocity (speed in x direction)
            horizontal_velocity = vel[0]  # X velocity

            # 7. Velocity reward using tolerance function
            move_reward = self._tolerance(
                horizontal_velocity,
                bounds=(self._MOVE_SPEED, float("inf")),
                margin=self._MOVE_SPEED / 2,
                value_at_margin=0.5,
                sigmoid="linear",
            )

            # 8. Combine stand and move rewards
            total_reward = stand_reward * (5.0 * move_reward + 1.0) / 6.0

            # 9. Check for termination height
            termination_height = 0.8  # If the walker falls below this height
            if torso_height < termination_height:
                total_reward = torch.tensor(0.0)  # Zero reward for falling

            rewards.append(total_reward)

        # Return tensor of rewards
        return torch.stack(rewards)

    # def termination_fn(self, states):
    #     terminations = []
    #     for env_state in states:
    #         # Get walker states
    #         walker_state = env_state["walker"]
    #         torso_height = walker_state["pos"][2]
    #         termination = torso_height < self._TERMINATION_HEIGHT
    #         terminations.append(termination)
    #     return torch.stack(terminations)



from metasim.cfg.objects import PrimitiveCubeMetaCfg, RigidObjMetaCfg
from metasim.cfg.tasks.base_task_metacfg import BaseTaskMetaCfg
from metasim.constants import BenchmarkType, PhysicStateType, TaskType
from metasim.utils import configclass


@configclass
class OpensdorRotUprightTextualSpeaker857MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="speaker",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/4445f4442a884999960e7e6660459095/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/4445f4442a884999960e7e6660459095_upright_textual/20240826-211926_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotUprightTextualSpeaker858MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="speaker",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/4445f4442a884999960e7e6660459095/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/4445f4442a884999960e7e6660459095_upright_textual/20240826-220813_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotUprightTextualSpeaker859MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="speaker",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/4445f4442a884999960e7e6660459095/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/4445f4442a884999960e7e6660459095_upright_textual/20240826-220632_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotUprightTextualSpeaker860MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="speaker",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/4445f4442a884999960e7e6660459095/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/4445f4442a884999960e7e6660459095_upright_textual/20240826-212553_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotUprightTextualSpeaker861MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="speaker",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/4445f4442a884999960e7e6660459095/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/4445f4442a884999960e7e6660459095_upright_textual/20240826-215510_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotUprightTextualSpeaker862MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="speaker",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/4445f4442a884999960e7e6660459095/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/4445f4442a884999960e7e6660459095_upright_textual/20240826-220106_no_interaction/trajectory-unified_wo_traj_v2.pkl"



from __future__ import annotations

import math

import numpy as np
import pybullet_data

import pybullet as p
from metasim.cfg.objects import ArticulationObjMetaCfg, PrimitiveCubeMetaCfg, PrimitiveSphereMetaCfg, RigidObjMetaCfg
from metasim.cfg.robots import BaseRobotMetaCfg
from metasim.cfg.scenario import ScenarioMetaCfg
from metasim.sim.base import GymEnvWrapper
from metasim.utils.math import convert_quat

from ..base import BaseSimHandler, EnvWrapper


class PybulletHandler(BaseSimHandler):
    def __init__(self, scenario: ScenarioMetaCfg, num_envs: int = 1, headless: bool = False):
        super().__init__(scenario, num_envs, headless=headless)

    def _build_pybullet(self):
        self.client = p.connect(p.GUI)
        p.setPhysicsEngineParameter(fixedTimeStep=1 / 60.0, numSolverIterations=300)
        p.setAdditionalSearchPath(pybullet_data.getDataPath())
        p.setGravity(0, 0, -9.81)

        # add plane
        self.plane_id = p.loadURDF("plane.urdf")
        # add agents
        self.object_ids = {}
        self.object_joint_order = {}
        self.camera_ids = {}
        for camera in self.cameras:
            # Camera parameters
            width, height = camera.width, camera.height

            # Camera position and target
            cam_eye = camera.pos  # Camera position in world coordinates
            cam_target = camera.look_at  # Where the camera is looking at
            cam_up = [0, 0, 1]  # Up vector

            # Compute view matrix
            view_matrix = p.computeViewMatrix(cam_eye, cam_target, cam_up)
            # Projection matrix (perspective camera)
            fov = camera.vertical_fov  # Field of view in degrees
            aspect = width / height  # Aspect ratio
            near_plane = camera.clipping_range[0]  # Near clipping plane
            far_plane = camera.clipping_range[1]  # Far clipping plane
            projection_matrix = p.computeProjectionMatrixFOV(fov, aspect, near_plane, far_plane)

            self.camera_ids[camera.name] = (width, height, view_matrix, projection_matrix)

        for object in [*self.objects, self.robot]:
            if isinstance(object, (ArticulationObjMetaCfg, BaseRobotMetaCfg)):
                pos = np.array([0, 0, 0])
                rot = np.array([1, 0, 0, 0])
                object_file = object.urdf_path
                useFixedBase = True
                flags = 0
                flags = flags | p.URDF_USE_SELF_COLLISION
                flags = flags | p.URDF_ENABLE_CACHED_GRAPHICS_SHAPES
                flags = flags | p.URDF_MAINTAIN_LINK_ORDER
                if True:  # object.collapse_fixed_joints :
                    flags = flags | p.URDF_MERGE_FIXED_LINKS

                curr_id = p.loadURDF(
                    object_file,
                    pos,
                    convert_quat(rot, to="xyzw"),
                    useFixedBase=useFixedBase,
                    flags=flags,
                    globalScaling=object.scale,
                )
                self.object_ids[object.name] = curr_id

                num_joints = p.getNumJoints(curr_id)
                cur_joint_names = [p.getJointInfo(curr_id, i)[1].decode("utf-8") for i in range(num_joints)]
                self.object_joint_order[object.name] = cur_joint_names

                # assert(num_joints == len(agent.dof.low))
                # assert(num_joints == len(agent.dof.high))
                # print(num_joints, agent.dof.init)
                # print(p.getJointStates(agent.instance, range(num_joints)))
                # assert(num_joints == len(object.dof.init))

                jointIndices = range(num_joints)

                if isinstance(object, BaseRobotMetaCfg):
                    p.setJointMotorControlMultiDofArray(
                        curr_id,
                        jointIndices,
                        p.POSITION_CONTROL,
                        # targetPositions = agent.dof.target
                    )

                ### TODO:
                # Add dof properties for articulated objects
                # if agent.dof.drive_mode == "position":
                #     p.setJointMotorControlMultiDofArray(
                #         agent.instance,
                #         jointIndices,
                #         p.POSITION_CONTROL,
                #         targetPositions = agent.dof.target
                #     )
                # elif agent.dof.drive_mode == "velocity":
                #     p.setJointMotorControlMultiDofArray(
                #         agent.instance,
                #         jointIndices,
                #         p.VELOCITY_CONTROL,
                #         targetVelocities = agent.dof.target
                #     )
                # elif agent.dof.drive_mode == "torque":
                #     p.setJointMotorControlMultiDofArray(
                #         agent.instance,
                #         jointIndices,
                #         p.TORQUE_CONTROL,
                #         forces = agent.dof.target
                #     )
                # p.resetJointStatesMultiDof(
                #     agent.instance,
                #     jointIndices,
                #     targetValues=[[x] for x in agent.dof.init],
                #     # targetVelocities=[0 for i in range(num_joints)]
                # )
                # p.resetBasePositionAndOrientation(agent.instance, pos, wxyz_to_xyzw(rot))

            elif isinstance(object, PrimitiveCubeMetaCfg):
                box_dimensions = [x * object.scale for x in object.half_size]
                pos = np.array([0, 0, 0])
                rot = np.array([1, 0, 0, 0])
                box_id = p.createCollisionShape(p.GEOM_BOX, halfExtents=box_dimensions)
                curr_id = p.createMultiBody(
                    baseMass=object.mass,
                    baseCollisionShapeIndex=box_id,
                    basePosition=pos,
                    baseOrientation=convert_quat(rot, to="xyzw"),
                )
                self.object_ids[object.name] = curr_id
                self.object_joint_order[object.name] = []

            elif isinstance(object, PrimitiveSphereMetaCfg):
                radius = object.radius * object.scale
                pos = np.array([0, 0, 0])
                rot = np.array([1, 0, 0, 0])
                sphere_id = p.createCollisionShape(p.GEOM_SPHERE, radius=radius)
                curr_id = p.createMultiBody(
                    baseMass=object.mass,
                    baseCollisionShapeIndex=sphere_id,
                    basePosition=pos,
                    baseOrientation=convert_quat(rot, to="xyzw"),
                )
                self.object_ids[object.name] = curr_id
                self.object_joint_order[object.name] = []

            elif isinstance(object, RigidObjMetaCfg):
                useFixedBase = object.fix_base_link
                pos = np.array([0, 0, 0])
                rot = np.array([1, 0, 0, 0])
                curr_id = p.loadURDF(
                    object.urdf_path,
                    pos,
                    convert_quat(rot, to="xyzw"),
                    useFixedBase=useFixedBase,
                    globalScaling=object.scale,
                )
                self.object_ids[object.name] = curr_id
                self.object_joint_order[object.name] = []

            else:
                raise ValueError(f"Object type {object} not supported")

            # p.resetBaseVelocity(curr_id, agent.vel, agent.ang_vel)
            ### TODO:
            # Add rigid body properties for objects
            # p.changeDynamics(
            #     agent.instance,
            #     -1,
            #     linearDamping=agent.rigid_shape_property.linear_damping,
            #     angularDamping=agent.rigid_shape_property.angular_damping,
            # )

        ### TODO:
        # Viewer configuration
        if not self.headless:
            camera_pos = np.array([1.5, -1.5, 1.5])
            camera_target = np.array([0.0, 0.0, 0.0])
            # if self.viewer_params.viewer_rot != None :
            #     camera_z = np.array([0.0, 0.0, 1.0])
            #     camera_rot = np.array(self.viewer_params.viewer_rot)
            #     camera_rot = camera_rot / np.linalg.norm(camera_rot)
            #     camera_target = camera_pos + quat_apply(camera_rot, camera_z)
            # else :
            #     camera_target = np.array(self.viewer_params.target_pos)
            direction_vector = camera_target - camera_pos
            yaw = -math.atan2(direction_vector[0], direction_vector[1])
            # Compute roll (Rotation around z axis)
            pitch = math.atan2(direction_vector[2], math.sqrt(direction_vector[0] ** 2 + direction_vector[1] ** 2))
            roll = 0
            p.resetDebugVisualizerCamera(
                cameraDistance=np.sqrt(np.sum(direction_vector**2)),
                cameraYaw=yaw * 180 / np.pi,
                cameraPitch=pitch * 180 / np.pi,
                cameraTargetPosition=camera_target,
            )

        # Prepare list of debug points and lines
        self.debug_points = []
        self.debug_lines = []

    def _apply_action(self, action, object):
        p.setJointMotorControlArray(
            object, range(action.shape[0]), controlMode=p.POSITION_CONTROL, targetPositions=action
        )

    def set_dof_targets(self, obj_name, target):
        # For multi-env version, rewrite this function

        action = target[0]
        action_arr = np.array([action["dof_pos_target"][name] for name in self.object_joint_order[self.robot.name]])
        self._apply_action(action_arr, self.object_ids[obj_name])

    def simulate(self):
        # # Rewrite this function for multi-env version
        # action = actions[0]

        # action_arr = np.array([action['dof_pos_target'][name] for name in self.object_joint_order[self.robot.name]])
        # self._apply_action(action_arr, self.object_ids[self.robot.name])

        p.stepSimulation()

        # return None, None, np.zeros(1), np.zeros(1), np.zeros(1)

    def launch(self):
        self._build_pybullet()
        self.already_disconnect = False

    def close(self):
        if not self.already_disconnect:
            p.disconnect(self.client)
            self.already_disconnect = True

    ############################################################
    ## Set states
    ############################################################
    def set_states(self, init_states, env_ids=None):
        # For multi-env version, rewrite this function

        self.init_states_to_set = init_states[0]

        for name, val in self.init_states_to_set.items():
            assert name in self.object_ids
            # Reset joint state
            obj_id = self.object_ids[name]

            if isinstance(self.object_dict[name], ArticulationObjMetaCfg):
                joint_names = self.object_joint_order[name]
                for i, joint_name in enumerate(joint_names):
                    p.resetJointState(obj_id, i, val["dof_pos"][joint_name])

            # Reset base position and orientation
            p.resetBasePositionAndOrientation(obj_id, val["pos"], convert_quat(val["rot"], to="xyzw"))

    ############################################################
    ## Get states
    ############################################################
    def get_states(self):
        # For multi-env version, rewrite this function

        states = {}
        for name, obj_id in self.object_ids.items():
            pos, rot = p.getBasePositionAndOrientation(obj_id)
            pos = np.array(pos)
            rot = np.array(rot)
            states[name] = {"pos": pos, "rot": rot, "dof_pos": {}}
            if isinstance(self.object_dict[name], ArticulationObjMetaCfg):
                joint_names = self.object_joint_order[name]
                for i, joint_name in enumerate(joint_names):
                    joint_state = p.getJointState(obj_id, i)
                    states[name]["dof_pos"][joint_name] = joint_state[0]

        states["cameras"] = {}

        for camera in self.cameras:
            width, height, view_matrix, projection_matrix = self.camera_ids[camera.name]
            img_arr = p.getCameraImage(width, height, view_matrix, projection_matrix)
            rgb_img = np.reshape(img_arr[2], (height, width, 4))
            depth_img = np.reshape(img_arr[3], (height, width))
            segmentation_mask = np.reshape(img_arr[4], (height, width))
            states["cameras"][camera.name] = {
                "rgb": rgb_img[:, :, :3],
            }
            # states[camera.name] = {
            #     "rgb": rgb_img,
            #     "depth": depth_img,
            #     "segmentation_mask": segmentation_mask,
            # }

        return states

    ############################################################
    ## Utils
    ############################################################
    def is_running(self):
        return True

    def get_object_joint_names(self, object):
        return self.object_joint_order[object.name]

    def get_robot_joint_limits(self):
        raise NotImplementedError


PybulletEnv: type[EnvWrapper[PybulletHandler]] = GymEnvWrapper(PybulletHandler)



from __future__ import annotations

import os
from typing import Literal

from loguru import logger as log
from tyro import MISSING

from metasim.utils.configclass import configclass
from metasim.utils.io_util import check_and_download
from metasim.utils.setup_util import get_robot, get_scene, get_task

from .cameras.camera import PinholeCameraMetaCfg
from .objects import BaseObjMetaCfg, PrimitiveCubeMetaCfg, PrimitiveSphereMetaCfg
from .randomization import RandomizationMetaCfg
from .render import RenderMetaCfg
from .robots.base_robot_metacfg import BaseRobotMetaCfg
from .scenes.base_scene_metacfg import SceneMetaCfg
from .tasks.base_task_metacfg import BaseTaskMetaCfg


def check_asset(obj: BaseObjMetaCfg, sim: Literal["isaaclab", "isaacgym", "pyrep", "pybullet", "sapien", "mujoco"]):
    ## TODO: add a primitive base class?
    if isinstance(obj, PrimitiveCubeMetaCfg) or isinstance(obj, PrimitiveSphereMetaCfg):
        return

    if sim in ["isaaclab"]:
        check_and_download(obj.filepath)
    elif sim in ["isaacgym", "pybullet", "sapien"]:
        check_and_download(obj.urdf_path)
    elif sim in ["mujoco"]:
        check_and_download(obj.mjcf_path)


@configclass
class ScenarioMetaCfg:
    ## Config system
    task: BaseTaskMetaCfg = MISSING
    robot: BaseRobotMetaCfg = MISSING
    scene: SceneMetaCfg | None = None
    """None means no scene"""
    cameras: list[PinholeCameraMetaCfg] = []
    render: RenderMetaCfg = RenderMetaCfg()
    random: RandomizationMetaCfg = RandomizationMetaCfg()

    ## Handlers
    sim: Literal["isaaclab", "isaacgym", "pyrep", "pybullet", "sapien", "mujoco"] = "isaaclab"
    renderer: Literal["isaaclab", "isaacgym", "pyrep", "pybullet", "sapien", "mujoco"] | None = None

    ## Others
    num_envs: int = 1
    try_add_table: bool = True
    object_states: bool = False
    split: Literal["train", "val", "test", "all"] = "all"
    headless: bool = False

    def __post_init__(self):
        ### Align configurations
        if (self.random.scene or self.scene is not None) and self.try_add_table:
            log.warning("try_add_table is set to False because scene randomization is enabled or a scene is specified")
            self.try_add_table = False

        ### Parse task and robot
        if isinstance(self.task, str):
            self.task = get_task(self.task)
        if isinstance(self.robot, str):
            self.robot = get_robot(self.robot)
        if isinstance(self.scene, str):
            self.scene = get_scene(self.scene)

        ### Check and download all the paths
        ## Object paths
        for obj in self.task.objects:
            check_asset(obj, self.sim)
        ## Robot paths
        check_asset(self.robot, self.sim)
        ## Scene paths
        if self.scene is not None:
            check_asset(self.scene, self.sim)
        ## Traj paths
        traj_filepath = self.task.traj_filepath
        if traj_filepath is None:
            return
        if (
            traj_filepath.find(".pkl") == -1
            and traj_filepath.find(".json") == -1
            and traj_filepath.find(".yaml") == -1
            and traj_filepath.find(".yml") == -1
        ):
            traj_filepath = os.path.join(traj_filepath, f"{self.robot.name}_v2.pkl.gz")
        check_and_download(traj_filepath)



import math

from metasim.cfg.checkers import JointPosChecker
from metasim.cfg.objects import ArticulationObjMetaCfg
from metasim.cfg.tasks import BaseTaskMetaCfg
from metasim.utils import configclass


@configclass
class FetchCloseBoxMetaCfg(BaseTaskMetaCfg):
    episode_length = 250
    objects = [
        ArticulationObjMetaCfg(
            name="box_base",
            filepath="roboverse_data/assets/rlbench/close_box/box_base/usd/box_base.usd",
            urdf_path="roboverse_data/assets/rlbench/close_box/box_base/urdf/box_base_unique.urdf",
            mjcf_path="roboverse_data/assets/rlbench/close_box/box_base/mjcf/box_base_unique.mjcf",
        ),
    ]
    traj_filepath = "metasim/cfg/tasks/fetch/fetch_example_v2.json"
    checker = JointPosChecker(
        obj_name="box_base",
        joint_name="box_joint",
        mode="le",
        radian_threshold=-14 / 180 * math.pi,
    )



from metasim.cfg.objects import PrimitiveCubeMetaCfg, RigidObjMetaCfg
from metasim.cfg.tasks.base_task_metacfg import BaseTaskMetaCfg
from metasim.constants import BenchmarkType, PhysicStateType, TaskType
from metasim.utils import configclass


@configclass
class OpensdorRotSidewaysTextualBox45MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/003_cracker_box_google_16k/003_cracker_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/003_sideways_textual/20240826-212342_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox46MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/003_cracker_box_google_16k/003_cracker_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/003_sideways_textual/20240826-220936_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox47MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/003_cracker_box_google_16k/003_cracker_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/003_sideways_textual/20240826-215229_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox48MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/003_cracker_box_google_16k/003_cracker_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/003_sideways_textual/20240826-212102_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox49MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/003_cracker_box_google_16k/003_cracker_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/003_sideways_textual/20240826-220627_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox50MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/003_cracker_box_google_16k/003_cracker_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/003_sideways_textual/20240826-211736_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox276MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/ycb_16k_backup/004_sugar_box_google_16k/004_sugar_box_google_16k.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/004_sideways_textual/20240826-211544_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox277MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/ycb_16k_backup/004_sugar_box_google_16k/004_sugar_box_google_16k.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/004_sideways_textual/20240826-215434_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox278MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/ycb_16k_backup/004_sugar_box_google_16k/004_sugar_box_google_16k.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/004_sideways_textual/20240826-212458_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox279MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/ycb_16k_backup/004_sugar_box_google_16k/004_sugar_box_google_16k.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/004_sideways_textual/20240826-222442_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox280MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/ycb_16k_backup/004_sugar_box_google_16k/004_sugar_box_google_16k.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/004_sideways_textual/20240826-220553_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox281MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/ycb_16k_backup/004_sugar_box_google_16k/004_sugar_box_google_16k.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/004_sideways_textual/20240826-221921_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox888MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/9660e0c0326b4f7386014e27717231ae/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/9660e0c0326b4f7386014e27717231ae_sideways_textual/20240826-221524_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox889MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/9660e0c0326b4f7386014e27717231ae/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/9660e0c0326b4f7386014e27717231ae_sideways_textual/20240826-213209_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox890MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/9660e0c0326b4f7386014e27717231ae/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/9660e0c0326b4f7386014e27717231ae_sideways_textual/20240826-221653_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox891MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/9660e0c0326b4f7386014e27717231ae/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/9660e0c0326b4f7386014e27717231ae_sideways_textual/20240826-213713_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox892MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/9660e0c0326b4f7386014e27717231ae/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/9660e0c0326b4f7386014e27717231ae_sideways_textual/20240826-221204_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox893MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/9660e0c0326b4f7386014e27717231ae/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/9660e0c0326b4f7386014e27717231ae_sideways_textual/20240826-220259_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox983MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/009_gelatin_box_google_16k/009_gelatin_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/009_sideways_textual/20240826-213709_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox984MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/009_gelatin_box_google_16k/009_gelatin_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/009_sideways_textual/20240826-215450_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox985MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/009_gelatin_box_google_16k/009_gelatin_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/009_sideways_textual/20240826-221744_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox986MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/009_gelatin_box_google_16k/009_gelatin_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/009_sideways_textual/20240826-220855_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox987MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/009_gelatin_box_google_16k/009_gelatin_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/009_sideways_textual/20240826-213336_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox988MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/009_gelatin_box_google_16k/009_gelatin_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/009_sideways_textual/20240826-211913_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1080MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/5e1a1527a0bd49ed8e473079392c31c8/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/5e1a1527a0bd49ed8e473079392c31c8_sideways_textual/20240826-215725_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1081MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/5e1a1527a0bd49ed8e473079392c31c8/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/5e1a1527a0bd49ed8e473079392c31c8_sideways_textual/20240826-221029_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1082MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/5e1a1527a0bd49ed8e473079392c31c8/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/5e1a1527a0bd49ed8e473079392c31c8_sideways_textual/20240826-212918_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1083MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/5e1a1527a0bd49ed8e473079392c31c8/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/5e1a1527a0bd49ed8e473079392c31c8_sideways_textual/20240826-222138_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1084MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/5e1a1527a0bd49ed8e473079392c31c8/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/5e1a1527a0bd49ed8e473079392c31c8_sideways_textual/20240826-211805_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1085MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/5e1a1527a0bd49ed8e473079392c31c8/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/5e1a1527a0bd49ed8e473079392c31c8_sideways_textual/20240826-213807_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1265MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/008_pudding_box_google_16k/008_pudding_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/008_sideways_textual/20240826-214113_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1266MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/008_pudding_box_google_16k/008_pudding_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/008_sideways_textual/20240826-220719_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1267MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/008_pudding_box_google_16k/008_pudding_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/008_sideways_textual/20240826-213004_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1268MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/008_pudding_box_google_16k/008_pudding_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/008_sideways_textual/20240826-223609_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1269MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path="data_isaaclab/assets/open6dor/ycb_16k_backup/008_pudding_box_google_16k/008_pudding_box_google_16k.urdf",
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/008_sideways_textual/20240826-222425_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1329MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f81ca566b008446eb704cad4844603b6/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f81ca566b008446eb704cad4844603b6_sideways_textual/20240826-223341_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1330MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f81ca566b008446eb704cad4844603b6/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f81ca566b008446eb704cad4844603b6_sideways_textual/20240826-221824_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1331MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f81ca566b008446eb704cad4844603b6/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f81ca566b008446eb704cad4844603b6_sideways_textual/20240826-220919_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1332MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f81ca566b008446eb704cad4844603b6/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f81ca566b008446eb704cad4844603b6_sideways_textual/20240826-212640_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1333MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f81ca566b008446eb704cad4844603b6/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f81ca566b008446eb704cad4844603b6_sideways_textual/20240826-214930_no_interaction/trajectory-unified_wo_traj_v2.pkl"


@configclass
class OpensdorRotSidewaysTextualBox1334MetaCfg(BaseTaskMetaCfg):
    source_benchmark = BenchmarkType.OPEN6DOR
    task_type = TaskType.TABLETOP_MANIPULATION
    episode_length = 600
    objects = [
        PrimitiveCubeMetaCfg(
            name="table",
            mass=1,
            color=[255, 255, 255],
            size=[0.6, 0.8, 0.3],
        ),
        RigidObjMetaCfg(
            name="box",
            urdf_path=(
                "data_isaaclab/assets/open6dor/objaverse_rescale/f81ca566b008446eb704cad4844603b6/material_2.urdf"
            ),
            physics=PhysicStateType.RIGIDBODY,
        ),
    ]
    traj_filepath = "data_isaaclab/source_data/open6dor/task_refine_rot_only/rot_ins/f81ca566b008446eb704cad4844603b6_sideways_textual/20240826-211337_no_interaction/trajectory-unified_wo_traj_v2.pkl"
